@@ -2,8 +2,11 @@
 
 from datetime import date, datetime
 from datetime import timedelta
+from decimal import Decimal
+from imio.smartweb.common.utils import rich_description
 from imio.smartweb.core.config import DIRECTORY_URL
 from imio.smartweb.core.contents.sections.views import SectionView
+from imio.smartweb.core.utils import batch_results
 from imio.smartweb.core.utils import get_json
 from imio.smartweb.locales import SmartwebMessageFactory as _
 from plone import api
@@ -39,6 +42,14 @@ class ContactView(SectionView):
         contact_type = contact.get("type").get("token")
         return "contact-type-{}".format(contact_type)
 
+    @property
+    def description(self):
+        contact = self.contact
+        if contact is None:
+            return ""
+        description = rich_description(contact.get("description"))
+        return description
+
     def data_geojson(self):
         """Return the contact geolocation as GeoJSON string."""
         current_lang = api.portal.get_current_language()[:2]
@@ -74,7 +85,7 @@ class ContactView(SectionView):
         json_images = get_json(images_url_request)
         if json_images is None or len(json_images.get("items", [])) == 0:
             return
-        return json_images.get("items")
+        return batch_results(json_images.get("items"), self.context.nb_results_by_batch)
 
     @property
     def days(self):
@@ -236,17 +247,17 @@ def get_schedule_for_today(schedule):
     morningend = schedule.get("morningend")
     afternoonstart = schedule.get("afternoonstart")
     afternoonend = schedule.get("afternoonend")
-    comment = schedule.get("comment")
+    comment = schedule.get("comment") or ""
     if morningstart:
-        morningstart = float(schedule.get("morningstart").replace(":", "."))
+        morningstart = Decimal(schedule.get("morningstart").replace(":", "."))
     if morningend:
-        morningend = float(schedule.get("morningend").replace(":", "."))
+        morningend = Decimal(schedule.get("morningend").replace(":", "."))
     if afternoonstart:
-        afternoonstart = float(schedule.get("afternoonstart").replace(":", "."))
+        afternoonstart = Decimal(schedule.get("afternoonstart").replace(":", "."))
     if afternoonend:
-        afternoonend = float(schedule.get("afternoonend").replace(":", "."))
+        afternoonend = Decimal(schedule.get("afternoonend").replace(":", "."))
 
-    now_str = float(datetime.now().strftime("%H.%M"))
+    now_str = Decimal(datetime.now().strftime("%H.%M"))
     if not morningstart and not morningend and not afternoonstart and not afternoonend:
         translated_closed = translate(_("Closed"), target_language=current_lang)
         return (
